require("dotenv").config();
const express = require("express");
const app = express();
const mongoose = require("mongoose");
var cors = require("cors");

mongoose.connect(process.env.DATABASE_URL);
const db = mongoose.connection;
db.on("error", (error) => console.error(error));
db.once("open", (error) => console.log("Connected to DB.."));

app.use(cors());
app.use(express.json());

//server health route
const healthRoute = require("./route/serverHealth");
app.use("/health", healthRoute);

//patient routes
const patientRegister = require("./route/patient-routes/register-route");
app.use("/patient/register", patientRegister);

const patientEmotion = require("./route/patient-routes/emotion-route");
app.use("/patient/emotion", patientEmotion);

const patientMentalState = require("./route/patient-routes/mental-state-router");
app.use("/patient/mentalstate", patientMentalState);

const patientRequest = require("./route/patient-routes/patient-requests");
app.use("/patient/request", patientRequest);

const patientNft = require("./route/patient-routes/nft-route");
app.use("/patient/createnft", patientNft);

const getNFTReqs = require("./route/patient-routes/get-nft-requests");
app.use("/nftrequests", getNFTReqs);

const patientLogin = require("./route/patient-routes/login-route");
app.use("/patient/login", patientLogin);

//practitioner routes
const practitionerRegister = require("./route/practitioner-routes/registration-route");
app.use("/practitioner/register", practitionerRegister);

const practitionerRecords = require("./route/practitioner-routes/records-route");
app.use("/practitioner/records", practitionerRecords);

const practitionerAcceptance = require("./route/practitioner-routes/acceptance-route");
app.use("/practitioner/request", practitionerAcceptance);

const practitionerNFTReq = require("./route/practitioner-routes/requestnft-route");
app.use("/practitioner/requestnft", practitionerNFTReq);

const practitionerAll = require("./route/practitioner-routes/get-practitioner-route");
app.use("/practitioner/allpractitioner", practitionerAll);

const practitionerUserReqs = require("./route/practitioner-routes/view-requests-route");
app.use("/practitioner/practitionerrequests", practitionerUserReqs);

const practitionerLogin = require("./route/practitioner-routes/login-route");
app.use("/practitioner/login", practitionerLogin);

const treatingPatients = require("./route/practitioner-routes/get-treating-patients-route");
app.use("/practitioner/treatingPatients", treatingPatients);

const assetCodes = require("./route/practitioner-routes/get-assetcode-practitioner-route");
app.use("/practitioner/getassetcode", assetCodes);

app.listen(process.env.SERVER_PORT, () =>
  console.log("Server started on port " + process.env.SERVER_PORT)
);
